package menudemo;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.e4.ui.model.application.MApplication;
import org.eclipse.e4.ui.model.application.ui.menu.MDirectMenuItem;
import org.eclipse.e4.ui.model.application.ui.menu.MMenu;
import org.eclipse.e4.ui.model.application.ui.menu.MMenuElement;
import org.eclipse.e4.ui.model.application.ui.menu.MMenuFactory;

public class DynamicMenuHelper {

	public static void addMenuItemToMenu(MApplication application, String parentMenuElementId, String menuItemLabel, String handlingClassURI) {
		MMenu target = (MMenu) findMenuElement(application, parentMenuElementId);
		MDirectMenuItem newItem = MMenuFactory.INSTANCE.createDirectMenuItem();
		newItem.setContributionURI(handlingClassURI);
		newItem.setLabel(menuItemLabel);
		target.getChildren().add(newItem);
	}
	
	public static void removeMenuItemFromMenu(MApplication application, String parentMenuElementId, String menuItemLabel) {
		MMenu target = (MMenu) findMenuElement(application, parentMenuElementId);
		List<MMenuElement> elements = target.getChildren();
		List<MMenuElement> found = new ArrayList<MMenuElement>();
		for (MMenuElement element: elements) {
			if (element.getLabel() != null && element.getLabel().equals(menuItemLabel)) {
				found.add(element);
			}
		}
		target.getChildren().removeAll(found);
	}
	
	public static void clearMenu(MApplication application, String parentMenuElementId) {
		MMenu target = (MMenu) findMenuElement(application, parentMenuElementId);
		target.getChildren().clear();
	}
	
	private static MMenuElement findMenuElement(MApplication application, String menuElementId) {
		MMenu mainMenu = application.getChildren().get(0).getMainMenu();
		return findMenuElement(mainMenu, menuElementId);
	}

	private static MMenuElement findMenuElement(MMenu mainMenu, String menuElementId) {
		for (MMenuElement child : mainMenu.getChildren()) {
			if (child.getElementId() != null && child.getElementId().equals(menuElementId))
				return child;
			if (child instanceof MMenu) {
				MMenuElement found = findMenuElement((MMenu)child, menuElementId);
				if (found != null)
					return found;
			}
		}
		return null;
	}
}

